@@ -20,11 +20,11 @@ function(dataset,
       { 
         if(is.na(file.plot.coord)){get(getOption("device"))()
           }else postscript(file.plot.coord)
-        setplot(seq(dataset$coord.lim[1],dataset$coord.lim[2],(dataset$coord.lim[2]-dataset$coord.lim[1])/10),
-                seq(dataset$coord.lim[3],dataset$coord.lim[4],(dataset$coord.lim[4]-dataset$coord.lim[3])/10))
+       ##  setplot(seq(dataset$coord.lim[1],dataset$coord.lim[2],(dataset$coord.lim[2]-dataset$coord.lim[1])/10),
+##                 seq(dataset$coord.lim[3],dataset$coord.lim[4],(dataset$coord.lim[4]-dataset$coord.lim[3])/10))
         
         plot(dataset$coord.indiv[1,],dataset$coord.indiv[2,],
-             xlab="x dataset$coordinates",ylab="y dataset$coordinates")
+             xlab="x dataset$coordinates",ylab="y dataset$coordinates",asp=)
         points(dataset$coord.nuclei[1,],dataset$coord.nuclei[2,],col=2)
         text(dataset$coord.nuclei[1,],dataset$coord.nuclei[2,],1:dataset$number.nuclei,pos=1,
              col=2,pch=2,cex=1.2)
@@ -38,15 +38,15 @@ function(dataset,
      {
        if(is.na(file.plot.tess)){get(getOption("device"))()
           }else postscript(file.plot.tess)
-        setplot(seq(dataset$coord.lim[1],dataset$coord.lim[2],(dataset$coord.lim[2]-dataset$coord.lim[1])/10),
-            seq(dataset$coord.lim[3],dataset$coord.lim[4],(dataset$coord.lim[4]-dataset$coord.lim[3])/10))
+     ##    setplot(seq(dataset$coord.lim[1],dataset$coord.lim[2],(dataset$coord.lim[2]-dataset$coord.lim[1])/10),
+##             seq(dataset$coord.lim[3],dataset$coord.lim[4],(dataset$coord.lim[4]-dataset$coord.lim[3])/10))
                 
        image(seq(from=dataset$coord.lim[1],to=dataset$coord.lim[2],length=dataset$npix[1]),
              seq(from=dataset$coord.lim[3],to=dataset$coord.lim[4],length=dataset$npix[2]),
              matrix(nr=dataset$npix[1],nc=dataset$npix[2],
                     dataset$color.nuclei[dataset$nearest.nucleus.grid],
                     byrow=F),
-             xlab="",ylab="",col=terrain.colors(dataset$npop))
+             xlab="",ylab="",col=terrain.colors(dataset$npop),asp=1)
        points(dataset$coord.nuclei[1,],dataset$coord.nuclei[2,],col=1,pch=".",cex=1.5)
        #text(dataset$coord.nuclei[1,],dataset$coord.nuclei[2,],dataset$color.nuclei,pos=2,cex=2)
        title(main="Population membership")
@@ -70,8 +70,8 @@ function(dataset,
                                    sep=""))
                 }
                 
-                setplot(seq(dataset$coord.lim[1],dataset$coord.lim[2],(dataset$coord.lim[2]-dataset$coord.lim[1])/10),
-                        seq(dataset$coord.lim[3],dataset$coord.lim[4],(dataset$coord.lim[4]-dataset$coord.lim[3])/10))
+##                 setplot(seq(dataset$coord.lim[1],dataset$coord.lim[2],(dataset$coord.lim[2]-dataset$coord.lim[1])/10),
+##                         seq(dataset$coord.lim[3],dataset$coord.lim[4],(dataset$coord.lim[4]-dataset$coord.lim[3])/10))
                 
                 FF <- rep(-999,prod(dataset$npix))
                 for(ipop in 1:dataset$npop)
@@ -86,7 +86,7 @@ function(dataset,
                       col=heat.colors(500),
                       xlab="",ylab="",
                       #breaks=seq(min(dataset$freq.grid),max(dataset$freq.grid),length=501),
-                      zlim=zlim.freq)
+                      zlim=zlim.freq,asp=1)
                ##  contour(seq(from=dataset$coord.lim[1],to=dataset$coord.lim[2],length=dataset$npix[1]),
 ##                       seq(from=dataset$coord.lim[3],to=dataset$coord.lim[4],length=dataset$npix[2]),
 ##                       matrix(nr=dataset$npix[2],nc=dataset$npix[1],FF,byrow=F),add=T)
@@ -120,12 +120,12 @@ function(dataset,
                                    iall,
                                    ".ps",
                                    sep=""))
-                 setplot(seq(dataset$coord.lim[1],dataset$coord.lim[2],(dataset$coord.lim[2]-dataset$coord.lim[1])/10),
-            seq(dataset$coord.lim[3],dataset$coord.lim[4],(dataset$coord.lim[4]-dataset$coord.lim[3])/10))
+               ##   setplot(seq(dataset$coord.lim[1],dataset$coord.lim[2],(dataset$coord.lim[2]-dataset$coord.lim[1])/10),
+##                          seq(dataset$coord.lim[3],dataset$coord.lim[4],(dataset$coord.lim[4]-dataset$coord.lim[3])/10))
                 
                 look <- as.image(x=t(dataset$coord.indiv),Z=FF)
                 image.plot(look,main=paste("Field of frequencies for locus #",
-                                  iloc,"allele #",iall))
+                                  iloc,"allele #",iall),asp=1)
                 points(dataset$coord.nuclei[1,],dataset$coord.nuclei[2,],col=2,cex=2,lwd=3)
                                         #text(dataset$coord.nuclei[1,],dataset$coord.nuclei[2,],dataset$color.nuclei,col=2,pos=1)
                 
@@ -151,11 +151,11 @@ function(dataset,
                              iloc,
                              ".ps",
                              sep=""))
-            setplot(seq(dataset$coord.lim[1],dataset$coord.lim[2],(dataset$coord.lim[2]-dataset$coord.lim[1])/10),
-                    seq(dataset$coord.lim[3],dataset$coord.lim[4],(dataset$coord.lim[4]-dataset$coord.lim[3])/10))
+          ##   setplot(seq(dataset$coord.lim[1],dataset$coord.lim[2],(dataset$coord.lim[2]-dataset$coord.lim[1])/10),
+##                     seq(dataset$coord.lim[3],dataset$coord.lim[4],(dataset$coord.lim[4]-dataset$coord.lim[3])/10))
             
             plot(dataset$coord.indiv[1,],dataset$coord.indiv[2,],type="n",cex=1,lwd=1,
-                 xlab="",ylab="")
+                 xlab="",ylab="",asp=1)
             title(paste("Genotypes at locus #",iloc))
             text(dataset$coord.indiv[1,],dataset$coord.indiv[2,],dataset$genotypes[,2*(iloc-1)+1],
                  cex=1,lwd=2,pos=2,adj=0.)
